/***********************************************************************
*
* Copyright (c) 2021-2023 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 500);

   QLabel *label = new QLabel();
   label->setText("Splitter Example");
   label->setAlignment(Qt::AlignHCenter);

   QFont font = label->font();
   font.setPointSize(11);
   label->setFont(font);

   QLabel *label_L = new QLabel{"LEFT PANE"};
   QTextEdit *text_L = new QTextEdit{"This text is located on the left side."};

   QLabel *label_R = new QLabel{"RIGHT PANE"};
   QTextEdit *text_R = new QTextEdit{"Text located on the right side of the Splitter"};

   QFrame *frame_L = new QFrame;
   frame_L->setLineWidth(2);
   frame_L->setFrameStyle(QFrame::Box);

   QVBoxLayout *layout_L = new QVBoxLayout(frame_L);
   layout_L->setContentsMargins(20, 10, 20, 15);
   layout_L->addWidget(label_L);
   layout_L->addWidget(text_L);

   QFrame *frame_R = new QFrame;
   frame_R->setLineWidth(2);
   frame_R->setFrameStyle(QFrame::Box);

   QVBoxLayout *layout_R = new QVBoxLayout(frame_R);
   layout_R->setContentsMargins(20, 10, 20, 15);
   layout_R->addWidget(label_R);
   layout_R->addWidget(text_R);

   QSplitter *splitter = new QSplitter;
   splitter->addWidget(frame_L);
   splitter->addWidget(frame_R);
   splitter->setHandleWidth(10);

   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QHBoxLayout *layout_button = new QHBoxLayout();
   layout_button->addStretch();
   layout_button->addWidget(pb_close);
   layout_button->addStretch();

   QVBoxLayout *layout_main = new QVBoxLayout(this);
   layout_main->setContentsMargins(40, 20, 40, 15);

   layout_main->addWidget(label);
   layout_main->addSpacing(20);
   layout_main->addWidget(splitter, 1);
   layout_main->addSpacing(20);
   layout_main->addLayout(layout_button);

   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
